create  view AgencyOfficeUnique (agency_code, office)
as
select  agency_code, office
from    LocExtAgency
group by 1, 2;
create view CountyInfo as
select cn.lid, cn.state, cn.county, c.countynum
from   countynum cn, counties c
where  cn.state  = c.state
and    cn.county = c.county;

CREATE VIEW DownStream AS
SELECT l.lid, l.name, l.elev, r.stream, 
       r.da, r.mile
FROM   location l, riverstat r
WHERE  l.lid = r.lid
AND    r.stream = 
       (SELECT r.stream 
	FROM   riverstat r
	WHERE  r.lid = l.lid);

CREATE VIEW FpInfo 
(lid, name, county, state, hsa, primary_back, secondary_back,
stream, bf, wstg, fs, fq, action_flow, pe, use_latest_fcst, 
proximity, reach,
group_id, ordinal, chg_threshold, rec_type,
minor, moderate, major)
as
SELECT l.lid, l.name, l.county, l.state, l.hsa,
  fp.primary_back, fp.secondary_back,
  r.stream, r.bf, r.wstg, r.fs, r.fq, r.action_flow, 
  r.primary_pe, r.use_latest_fcst,
  d.proximity, d.reach,
  fp.group_id, fp.ordinal, fp.chg_threshold, fp.rec_type,
  f.minor_stage, f.moderate_stage, f.major_stage
FROM Location l
    LEFT OUTER JOIN Floodcat f
    ON l.lid = f.lid
    LEFT OUTER JOIN Descrip d
    ON l.lid = d.lid,
    Riverstat r, RpfFcstPoint fp
WHERE (l.type not like '%I%' OR l.type IS NULL)
and   l.lid = r.lid
and   l.lid = fp.lid;

CREATE VIEW HvStation (lid, name, lat, lon,
		       stream_name, primary_pe, 
		       flood_stage, flood_flow, action_stage, action_flow, 
                       disp_class, is_dcp, is_observer, telem_type) AS 
		
SELECT l.lid, l.name, l.lat, l.lon,
       r.stream, r.primary_pe, r.fs, r.fq, r.wstg, r.action_flow, 
       s.disp_class, s.dcp, s.observer, s.telem_type
       
FROM   Location l
       LEFT OUTER JOIN Riverstat r
       ON l.lid = r.lid, 
       StnClass s
WHERE  l.lid = s.lid;

CREATE   VIEW HwStages (lid, fs, wstg, ms) AS
SELECT   r.lid, r.fs, r.wstg, MAX(c.stage)
FROM     riverstat r, crest c
WHERE    r.lid = c.lid
GROUP BY 1, 2, 3;
CREATE VIEW LocClass (lid, name, lat, lon, wfo, hsa, post,
                      disp_class, is_dcp, is_observer, telem_type) AS 
		
SELECT l.lid, l.name, l.lat, l.lon, l.wfo, l.hsa, l.post,
       s.disp_class, s.dcp, s.observer, s.telem_type
       
FROM   Location l 
       LEFT OUTER JOIN StnClass s
       
ON     l.lid = s.lid;

CREATE VIEW LocTransmit AS
SELECT lid, call_sign
FROM countynum lc,  countytransmit ct
WHERE lc.county=ct.county
AND   lc.state =ct.state
AND call_sign IN
	(SELECT call_sign
	FROM nwrtransmitter
	WHERE use_transmitter != 'F')
GROUP BY 1,2;

CREATE VIEW LocView AS 
SELECT l.lid, l.name, l.lat, l.lon, l.rb, l.state, l.county, l.type, l.wfo,
       l.hsa,l.post, r.stream, r.gsno
FROM   location l LEFT OUTER JOIN riverstat r
ON     l.lid = r.lid;

CREATE VIEW LocWfo AS
SELECT l.lid, c.county, c.state,
c.wfo, c.primary_back, c.secondary_back
FROM location l, counties c          
WHERE l.county = c.county
AND   l.state = c.state;

create view ParamName as
select i.lid, i.pe, s.name 
from   IngestFilter i, ShefPe s
where  i.pe = s.pe;

create view PrevProd
as
select product_id, producttime, postingtime, prodtype, issnum
from   TextProduct
where  prodtype NOT IN ('O', 'F', 'C');

create view sigstages 
(
 lid, stream, tide, 
 mile, fs, bf, wstg, zd,
 minor, moderate, major,
 record
)
as
select r.lid, r.stream, r.tide, 
       r.mile, r.fs, r.bf, r.wstg, r.zd,
       f.minor_stage, f.moderate_stage, f.major_stage,
       max(c.stage)
from   riverstat r 
       LEFT OUTER JOIN floodcat f
       ON r.lid = f.lid
       LEFT OUTER JOIN crest c
       ON r.lid = c.lid
group by 1,2,3,4,5,6,7,8,9,10,11;

CREATE VIEW StationList (lid, name, firstname, lastname, rb, county,
			 wfo, hphone, ophone) AS
SELECT l.lid, l.name, o.firstname, o.lastname, l.rb, l.county, l.wfo,
       o.hphone, o.phone
FROM   location l LEFT OUTER JOIN observer o
ON     l.lid = o.lid;

create view StatProf
as
select l.lid, l.name,
       r.primary_pe, r.stream, r.fs, r.wstg, r.fq, r.action_flow, r.zd, r.mile,
       d.reach, d.proximity
from   location l, riverstat r
       LEFT OUTER JOIN descrip d
       ON r.lid = d.lid
WHERE  l.lid = r.lid
	and    (l.type not like '%I%' OR l.type IS NULL)
	and    r.zd is not null
	and    r.mile is not null;

CREATE VIEW ZoneInfo AS
SELECT z.lid, z.state, z.zonenum, e.descr
FROM   zonenum z, eligzon e
WHERE  z.state = e.state
AND    z.zonenum = e.zonenum;
